@@ -6,6 +6,37 @@
 
 #include "includes.h"
 
+/*
+ * Standard function to report an error to the user.
+ */
+void
+error(str)
+char	*str;	/* must be a constant string, temporary strings don't work */
+{
+	error_str = str;
+#if	!SILENT
+	set_color(2);	/* set color to red */
+	printf("%s\n", str);
+	default_color();
+#endif
+}
+
+/*
+ * Standard function to report a warning to the user.
+ */
+void
+warning(str)
+char	*str;
+{
+#if	!SILENT
+	if (debug_level >= 0) {
+		set_color(1);	/* set color to yellow */
+		printf("Warning: %s\n", str);
+		default_color();
+	}
+#endif
+}
+
 /*
  * This is called when the maximum expression size has been exceeded.
  *
@@ -113,7 +144,7 @@ clear_sign_array()
 }
 
 /*
- * Register all sign variables.
+ * Register all sign variables in all equation spaces.
  */
 void
 set_sign_array()
@@ -238,10 +269,9 @@ next_espace()
 	if (i < 0) {
 		error(_("Out of free equation spaces."));
 #if	!SILENT
-		printf(_("Use the clear command on unnecessary equations or\n"));
-		printf(_("restart with \"clear all\" and try again.\n"));
+		printf(_("Use the clear command on unnecessary equations and try again.\n"));
 #endif
-		longjmp(jmp_save, 3);
+		longjmp(jmp_save, 3);	/* do not return */
 	}
 	return i;
 }
@@ -286,9 +316,11 @@ long		v;	/* standard Mathomatic variable */
 {
 	int	j;
 
-	for (j = 0; j < n; j += 2) {
-		if (p1[j].kind == VARIABLE && p1[j].token.variable == v) {
-			return true;
+	if (v) {
+		for (j = 0; j < n; j += 2) {
+			if (p1[j].kind == VARIABLE && p1[j].token.variable == v) {
+				return true;
+			}
 		}
 	}
 	return false;
@@ -561,6 +593,7 @@ int	n;		/* maximum size of "string" in bytes */
 	input_column = strlen(prompt_str);
 #if	READLINE
 	if (readline_enabled) {
+		rl_inhibit_completion = true;	/* turn off readline file name completion */
 		cp = readline(prompt_str);
 		if (cp == NULL) {
 			fprintf(gfp, _("\nEnd of input.\n"));
