@@ -50,16 +50,10 @@
 #define	MAX_CMD_LEN	PATH_MAX			/* maximum command line length (not equations), also max file name length */
 #define	MAX_PROMPT_LEN	STANDARD_SCREEN_COLUMNS		/* maximum length of prompts */
 
-#if	CYGWIN
-#define RC_FILE		"mathomatic.rc"	/* file of set options in the Mathomatic directory under Windows */
-#else
-#define RC_FILE		".mathomaticrc"	/* file of set options read at startup from $HOME */
-#endif
-
 /*
  * The following defines the maximum number of equation spaces that can be allocated.
  */
-#define	N_EQUATIONS	50
+#define	N_EQUATIONS	100
 
 /*
  * The following defines the default maximum mathematical expression size.
@@ -96,7 +90,7 @@ typedef union {
 	double	constant;	/* internal storage for mathematical constants */
 	long	variable;	/* internal storage for mathematical variables */
 /* predefined special variables follow (order is important) */
-#define	V_NULL		0L	/* null variable (display nothing) */
+#define	V_NULL		0L	/* null variable, should never be stored in an expression */
 #define	V_E		1L	/* the constant "e" or "e#" */
 #define	V_PI		2L	/* the constant "pi" or "pi#" */
 #define	IMAGINARY	3L	/* the imaginary constant "i" or "i#" */
@@ -112,6 +106,7 @@ typedef union {
 #define	POWER		6	/* a ^ b */
 #define	FACTORIAL	7	/* a! */
 #define	NEGATE		8	/* special parser operator */
+#define IDIVIDE		9	/* a // b */
 } storage_type;
 
 typedef	struct {		/* storage structure for each token in an expression */
@@ -125,14 +120,12 @@ typedef struct {		/* variable sort data structure */
 	int	count;		/* number of times the variable occurs */
 } sort_type;
 
-/* Debugging and error reporting macros: */
+/* Debugging macros: */
 #if	SILENT
-#define	error(str)			{ error_str = str; }	/* must be a constant string, temp strings don't work */
 #define	list_tdebug(level)
 #define	side_debug(level, p1, n1)
 #define debug_string(level, str)
 #else
-#define	error(str)			{ error_str = str; printf("%s\n", str); }
 #define list_tdebug(level)		list_debug(level, tlhs, n_tlhs, trhs, n_trhs)
 #define	side_debug(level, p1, n1)	list_debug(level, p1, n1, NULL, 0)
 #define debug_string(level, str)	{ if (debug_level >= (level)) printf("%s\n", str); }
