@@ -190,10 +190,9 @@ int	product_flag;	/* true for product, otherwise sum */
 	}
 	if (*cp) {
 		if (*cp == '=') {
-			cp1 = skip_space(cp + 1);
-		} else {
-			cp1 = cp;
+			cp++;
 		}
+		cp1 = cp;
 	} else {
 		list_var(v, 0);
 		snprintf(prompt_str, sizeof(prompt_str), "%s = ", var_str);
@@ -225,7 +224,7 @@ int	product_flag;	/* true for product, otherwise sum */
 	if (*cp) {
 		cp1 = cp;
 		step = fabs(strtod(cp1, &cp));
-		if (step <= 0.0 || step >= MAX_K_INTEGER || cp1 == cp) {
+		if (cp1 == cp || step <= 0.0 || step >= MAX_K_INTEGER) {
 			error(_("Invalid step."));
 			return false;
 		}
@@ -234,7 +233,7 @@ int	product_flag;	/* true for product, otherwise sum */
 		return false;
 	count_down = (end < start);
 	if (fmod(fabs(start - end) / step, 1.0)) {
-		error(_("Warning: end value not reached."));
+		warning(_("End value not reached."));
 	}
 	if (product_flag) {
 		dest[0] = one_token;
@@ -589,7 +588,7 @@ display_current_directory()
 }
 
 /*
- * Output the current set options in a format suitable for RC_FILE.
+ * Output the current set options in a format suitable for reading back in.
  */
 void
 output_options()
@@ -654,17 +653,24 @@ output_options()
 }
 
 /*
- * Return true if "cp" points to a negative word.
+ * Skip over a yes/no indicator and return true if *cpp pointed to a negative word.
  */
 int
-is_no(cp)
-char	*cp;
+skip_no(cpp)
+char	**cpp;
 {
-	if (strcmp_tospace(cp, "no") == 0
-	    || strcmp_tospace(cp, "off") == 0
-	    || strcmp_tospace(cp, "false") == 0) {
+	if (strcmp_tospace(*cpp, "no") == 0
+	    || strcmp_tospace(*cpp, "not") == 0
+	    || strcmp_tospace(*cpp, "off") == 0
+	    || strcmp_tospace(*cpp, "false") == 0) {
+		*cpp = skip_param(*cpp);
 		return true;
 	}
+	if (strcmp_tospace(*cpp, "yes") == 0
+	    || strcmp_tospace(*cpp, "on") == 0
+	    || strcmp_tospace(*cpp, "true") == 0) {
+		*cpp = skip_param(*cpp);
+	}
 	return false;
 }
 
@@ -681,15 +687,10 @@ char	*cp;
 	int	negate;
 	char	*cp1;
 
-next_option:
 	cp = skip_space(cp);
 	if (*cp == '\0') {
 		return true;
 	}
-	negate = is_no(cp);
-	if (negate) {
-		cp = skip_param(cp);
-	}
 #if	!SECURE
 	if (strncasecmp(cp, "dir", 3) == 0) {
 		cp = skip_param(cp);
@@ -707,6 +708,7 @@ next_option:
 		return true;
 	}
 #endif
+	negate = skip_no(&cp);
 #if	!SILENT
 	if (strncasecmp(cp, "debug", 5) == 0) {
 		cp = skip_param(cp);
@@ -721,7 +723,7 @@ next_option:
 			cp = cp1;
 			debug_level = i;
 		}
-		goto next_option;
+		return true;
 	}
 #endif
 	if (strncasecmp(cp, "special", 7) == 0) {
@@ -749,49 +751,49 @@ next_option:
 			cp = cp1;
 			screen_columns = i;
 		}
-		goto next_option;
+		return true;
 	}
 	if (strncasecmp(cp, "autosolve", 9) == 0) {
 		cp = skip_param(cp);
 		autosolve = !negate;
-		goto next_option;
+		return true;
 	}
 	if (strncasecmp(cp, "autocalc", 8) == 0) {
 		cp = skip_param(cp);
 		autocalc = !negate;
-		goto next_option;
+		return true;
 	}
 	if (strncasecmp(cp, "case", 4) == 0) {
 		cp = skip_param(cp);
 		case_sensitive_flag = !negate;
-		goto next_option;
+		return true;
 	}
 	if (strncasecmp(cp, "display2d", 7) == 0) {
 		cp = skip_param(cp);
 		display2d = !negate;
-		goto next_option;
+		return true;
 	}
 	if (strncasecmp(cp, "preserve", 8) == 0) {
 		cp = skip_param(cp);
 		preserve_roots = !negate;
-		goto next_option;
+		return true;
 	}
-	if (strncasecmp(cp, "true_modulus", 4) == 0) {
+	if (strncasecmp(cp, "true_modulus", 8) == 0) {
 		cp = skip_param(cp);
 		true_modulus = !negate;
-		goto next_option;
+		return true;
 	}
 	if (strncasecmp(cp, "color", 5) == 0) {
 		cp = skip_param(cp);
 		color_flag = !negate;
 		cur_color = -1;
-		goto next_option;
+		return true;
 	}
 	if (strncasecmp(cp, "bold", 4) == 0) {
 		cp = skip_param(cp);
 		bold_colors = !negate;
 		cur_color = -1;
-		goto next_option;
+		return true;
 	}
 	if (strncasecmp(cp, "finance", 7) == 0) {
 		cp = skip_param(cp);
@@ -800,26 +802,31 @@ next_option:
 		} else {
 			i = decstrtol(cp, &cp1);
 			if (cp == cp1) {
-				i = 2;
+				if (*cp1 == '\0') {
+					i = 2;
+				} else {
+					error(_("Please specify the number of digits."));
+					return false;
+				}
 			}
-			if (i > 50) {
-				error(_("Maximum is 50."));
+			if (i < 0 || i > 50) {
+				error(_("Minimum is 0, maximum is 50."));
 				return false;
 			}
 			cp = cp1;
 			finance_option = i;
 		}
-		goto next_option;
+		return true;
 	}
 	if (strncasecmp(cp, "factor_integers", 6) == 0) {
 		cp = skip_param(cp);
 		factor_int_flag = !negate;
-		goto next_option;
+		return true;
 	}
 	if (strncasecmp(cp, "right_associative_power", 5) == 0) {
 		cp = skip_param(cp);
 		right_associative_power = !negate;
-		goto next_option;
+		return true;
 	}
 	error(_("Unknown set option."));
 	return false;
@@ -1293,7 +1300,7 @@ calc_again:
 			list_proc(lhs[i], n_lhs[i], false);
 			fprintf(gfp, " = ");
 		}
-		list_fact(tlhs, &n_tlhs, factor_flag);
+		list_factor(tlhs, &n_tlhs, factor_flag);
 		fprintf(gfp, "\n\n");
 	}
 	if (value_entered && repeat_flag)
@@ -1394,9 +1401,7 @@ char	*cp;
 		error(_("Cannot compare an equation with itself."));
 		return false;
 	}
-#if	!SILENT
 	fprintf(gfp, _("Comparing #%d with #%d...\n"), i + 1, j + 1);
-#endif
 	if (n_rhs[i] == 0 || n_rhs[j] == 0) {
 		if (n_rhs[i] == 0 && n_rhs[j] == 0) {
 			simp_loop(lhs[i], &n_lhs[i]);
@@ -1575,11 +1580,11 @@ char	*cp;
 		list_var(v_tmp, 0);
 		fprintf(gfp, _("Polynomial division successful using base variable (%s).\n"), var_str);
 		fprintf(gfp, _("The quotient is:\n"));
-		es_make_fractions_and_group(tlhs, &n_tlhs);
-		list_fact(tlhs, &n_tlhs, false);
+		display_fractions_and_group(tlhs, &n_tlhs);
+		list_factor(tlhs, &n_tlhs, false);
 		fprintf(gfp, _("\n\nThe remainder is:\n"));
-		es_make_fractions_and_group(trhs, &n_trhs);
-		list_fact(trhs, &n_trhs, false);
+		display_fractions_and_group(trhs, &n_trhs);
+		list_factor(trhs, &n_trhs, false);
 		fprintf(gfp, "\n");
 	} else {
 		fprintf(gfp, _("Polynomial division failed.\n"));
@@ -1592,8 +1597,8 @@ char	*cp;
 	if (j) {
 		simp_divide(trhs, &n_trhs);
 		fprintf(gfp, _("Polynomial GCD (Euclidean algorithm iterations = %d):\n"), j);
-		es_make_fractions_and_group(trhs, &n_trhs);
-		list_fact(trhs, &n_trhs, false);
+		display_fractions_and_group(trhs, &n_trhs);
+		list_factor(trhs, &n_trhs, false);
 		fprintf(gfp, "\n");
 	} else {
 		fprintf(gfp, _("No univariate polynomial GCD found.\n"));
@@ -1851,17 +1856,24 @@ char	*cp;
 	int	int_flag = false, displayed = false;
 	char	*cp1;
 
-	if (strcmp_tospace(cp, "c") == 0 || strcmp_tospace(cp, "c++") == 0) {
-		cp = skip_param(cp);
-	} else if (strcmp_tospace(cp, "java") == 0) {
-		cp = skip_param(cp);
-		language = 1;
-	} else if (strcmp_tospace(cp, "python") == 0) {
-		cp = skip_param(cp);
-		language = 2;
-	} else if (strcmp_tospace(cp, "int") == 0 || strcmp_tospace(cp, "integer") == 0) {
-		cp = skip_param(cp);
-		int_flag = true;
+	for (;; cp = skip_param(cp)) {
+		if (strcmp_tospace(cp, "c") == 0 || strcmp_tospace(cp, "c++") == 0) {
+			language = 0;
+			continue;
+		}
+		if (strcmp_tospace(cp, "java") == 0) {
+			language = 1;
+			continue;
+		}
+		if (strcmp_tospace(cp, "python") == 0) {
+			language = 2;
+			continue;
+		}
+		if (strcmp_tospace(cp, "int") == 0 || strcmp_tospace(cp, "integer") == 0) {
+			int_flag = true;
+			continue;
+		}
+		break;
 	}
 	do {
 		cp1 = cp;
@@ -1875,22 +1887,27 @@ char	*cp;
 		for (; i <= j; i++) {
 			if (n_lhs[i] > 0) {
 				if (n_rhs[i] == 0 || n_lhs[i] != 1 || lhs[i][0].kind != VARIABLE) {
-					error(_("Not a solved equation."));
-					continue;
+					warning(_("Can't make assignment statement because this is not an equation."));
 				}
 				approximate_roots = true;
-				simp_i(rhs[i], &n_rhs[i]);
-				approximate_roots = false;
+				simp_i(lhs[i], &n_lhs[i]);
 				if (int_flag) {
-					uf_repeat_always(rhs[i], &n_rhs[i]);
+					uf_repeat_always(lhs[i], &n_lhs[i]);
 				}
+				if (n_rhs[i] > 0) {
+					simp_i(rhs[i], &n_rhs[i]);
+					if (int_flag) {
+						uf_repeat_always(rhs[i], &n_rhs[i]);
+					}
+				}
+				approximate_roots = false;
 				make_fractions_and_group(i);
-				if (int_flag && !int_expr(rhs[i], n_rhs[i])) {
-					error(_("Not an integer equation."));
-					continue;
+				if (int_flag && (!int_expr(lhs[i], n_lhs[i]) || !int_expr(rhs[i], n_rhs[i]))) {
+					warning(_("Not an integer expression."));
+				}
+				if (list_c_equation(i, language, int_flag) > 0) {
+					displayed = true;
 				}
-				list_c_equation(i, language, int_flag);
-				displayed = true;
 			}
 		}
 	} while (*cp);
@@ -2389,7 +2406,7 @@ FILE	*fp;
 			}
 			set_error_level(cp);
 			if (!process(cp)) {
-				longjmp(jmp_save, 3);
+				longjmp(jmp_save, 3);	/* jump to the above error trap */
 			}
 		}
 	}
@@ -2470,7 +2487,7 @@ edit_again:
 	}
 	clear_all();
 	if (!read_cmd(cp)) {
-		if (pause_cmd(_("Prepare to run the editor"))) {
+		if (pause_cmd(_("Prepare to rerun the editor"))) {
 			goto edit_again;
 		}
 	}
