@@ -633,7 +633,7 @@ loop_again:
 		dest[i1].level++;
 	uf_simp(dest, &n1);
 	if (!flag && exp_contains_infinity(dest, n1)) {
-		debug_string(0, _("Singularity warning: result invalid because it contains infinity or NaN."));
+		warning(_("Result invalid because it contains infinity or NaN."));
 		flag = true;
 	}
 	side_debug(1, dest, n1);
