@@ -1,7 +1,7 @@
 /*
  * General floating point GCD routine and associated code for Mathomatic.
  *
- * Copyright (C) 1987-2007 George Gesslein II.
+ * Copyright (C) 1987-2008 George Gesslein II.
  */
 
 #include "includes.h"
@@ -126,17 +126,13 @@ double	*denominatorp;	/* returned denominator */
 	if (fmod(d, 1.0) == 0.0) {
 		return true;
 	}
-#if	true	/* set true for more integer oriented math */
 	k3 = fabs(d) * epsilon;
-#else
-	k3 = fabs(d) * small_epsilon;
-#endif
 	k4 = my_round(d);
 	if (k4 != 0.0 && fabs(k4 - d) <= k3) {
 		*numeratorp = k4;
 		return true;
 	}
-/* try to convert non-integer, floating point value in "d" to a fraction: */
+/* try to convert non-integer floating point value in "d" to a fraction: */
 	if ((divisor = gcd(1.0, d)) > epsilon) {
 		numerator = my_round(d / divisor);
 		denominator = my_round(1.0 / divisor);
@@ -157,10 +153,10 @@ double	*denominatorp;	/* returned denominator */
 			return false;	/* result is too inaccurate */
 		}
 		if (fmod(numerator, 1.0)) {
-			error("Internal error: Numerator not integral.");
+			error("Internal error: Numerator is not integral.");
 		}
 		if (fmod(denominator, 1.0)) {
-			error("Internal error: Denominator not integral.");
+			error("Internal error: Denominator is not integral.");
 		}
 		*numeratorp = numerator;
 		*denominatorp = denominator;
