@@ -39,7 +39,7 @@ int		case_sensitive_flag = true;		/* "set case_sensitive" flag */
 int		factor_int_flag;			/* factor integers when displaying expressions */
 int		display2d = true;			/* "set display2d" flag */
 int		preserve_roots = true;			/* set option to preserve roots like (2^.5) */
-int		true_modulus;				/* true for mathematically correct modulus */
+int		true_modulus = true;				/* true for mathematically correct modulus */
 volatile int	screen_columns = STANDARD_SCREEN_COLUMNS;	/* screen width of the terminal; 0 = infinite */
 volatile int	screen_rows = STANDARD_SCREEN_ROWS;		/* screen height of the terminal; 0 = infinite */
 int		finance_option;				/* for displaying dollars and cents */
@@ -48,6 +48,7 @@ int		autocalc = true;			/* Allows automatically calculating a numerical expressi
 char		special_variable_character = '\\';	/* user defined special character for variable names */
 int		integer_coefficients = true;		/* if true, prefer displaying all integer coefficients */
 int		right_associative_power;		/* if true, evaluate power operators right to left */
+int		power_starstar;				/* if true, display power operator as "**" */
 #if	!SILENT
 int		debug_level;				/* current debug level */
 #endif
