@@ -38,30 +38,30 @@ static com_type com_list[] = {
 {	"derivative",	"differentiate",	derivative_cmd,		"[variable or \"all\"] [order]",			"Symbolically differentiate and simplify, order times." },
 {	"display",	NULL,			display_cmd,		"[\"factor\"] [equation-number-range]",			"Display equation spaces in multi-line fraction format." },
 #if	!LIBRARY
-{	"divide",	NULL,			divide_cmd,		"[variable]",						"Prompt for 2 polynomials/numbers and divide.  Display result and GCD." },
+{	"divide",	NULL,			divide_cmd,		"[variable]",						"Prompt for 2 numbers or polynomials and divide. Give result and GCD." },
 #endif
 {	"echo",		NULL,			echo_cmd,		"[text]",						"Output a line of text, followed by a newline." },
 #if	!LIBRARY && (UNIX || CYGWIN) && !SECURE
 {	"edit",		NULL,			edit_cmd,		"[file-name]",						"Edit all equation spaces or an input file." },
 #endif
 {	"eliminate",	NULL,			eliminate_cmd,		"[\"repeat\"] variables or \"all\" [\"using\" equation-number]",	"Substitute the specified variables with solved equations." },
-{	"extrema",	"stationary",		extrema_cmd,		"[variable] [order]",					"Find possible local minimums and maximums of the current expression." },
+{	"extrema",	NULL,			extrema_cmd,		"[variable] [order]",					"Find possible local minimums and maximums of the current expression." },
 {	"factor",	NULL,			factor_cmd,		"[\"number\" [integers]] or [equation-number-range] [variables]",	"Factor given integers or factor variables in expressions." },
 {	"fraction",	NULL,			fraction_cmd,		"[equation-number-range]",				"Convert expressions with algebraic fractions into a single fraction." },
 {	"help",		NULL,			help_cmd,		"[topic or command-names]",				"Short, built-in help." },
-{	"imaginary",	NULL,			imaginary_cmd,		"[variable]",						"Copy the imaginary part of an expression (see the \"real\" command)." },
+{	"imaginary",	NULL,			imaginary_cmd,		"[variable]",						"Copy the imaginary part of an expression (see real command)." },
 {	"integrate",	"integral",		integrate_cmd,		"[\"constant\" or \"definite\"] variable [order]",	"Symbolically integrate polynomials, order times." },
 {	"laplace",	NULL,			laplace_cmd,		"[\"inverse\"] variable",				"Compute the Laplace or inverse Laplace transform of polynomials." },
 {	"limit",	NULL,			limit_cmd,		"variable expression",					"Take the limit as variable goes to expression." },
 {	"list",		NULL,			list_cmd,		"[\"export\" or \"maxima\"] [equation-number-ranges]",	"Display equation spaces in single line format." },
 #if	!LIBRARY
 {	"nintegrate",	NULL,			nintegrate_cmd,		"[\"trapezoid\"] variable [partitions]",		"Approximate the definite integral using Simpson's rule."},
-{	"optimize",	NULL,			optimize_cmd,		"[equation-number-range]",				"Split up an equation into smaller multiple equations." },
+{	"optimize",	NULL,			optimize_cmd,		"[equation-number-range]",				"Split up an equation into smaller, more efficient equations." },
 #endif
 #if	!LIBRARY
-{	"pause",	NULL,			pause_cmd,		"[text]",						"Wait for user to press the Enter key.  Optionally display a message." },
+{	"pause",	NULL,			pause_cmd,		"[text]",						"Wait for user to press the Enter key. Optionally display a message." },
 #endif
-{	"product",	NULL,			product_cmd,		"variable start end [step]",				"Compute the product as variable goes from start to end." },
+{	"product",	NULL,			product_cmd,		"variable start end [step-size]",			"Compute the product as variable goes from start to end." },
 #if	READLINE
 {	"push",		NULL,			push_cmd,		"[equation-number-range]",				"Push specified equation spaces into the readline history." },
 #endif
@@ -71,7 +71,7 @@ static com_type com_list[] = {
 #if	!SECURE
 {	"read",		NULL,			read_cmd,		"file-name",						"Read in a text file as if it was typed in." },
 #endif
-{	"real",		NULL,			real_cmd,		"[variable]",						"Copy the real part of an expression (see the \"imaginary\" command)." },
+{	"real",		NULL,			real_cmd,		"[variable]",						"Copy the real part of an expression (see imaginary command)." },
 {	"replace",	NULL,			replace_cmd,		"[variables [\"with\" expression]]",			"Substitute variables in the current equation with expressions." },
 #if	!LIBRARY
 {	"roots",	NULL,			roots_cmd,		"root real-part imaginary-part",			"Display all the roots of a complex number." },
@@ -82,11 +82,11 @@ static com_type com_list[] = {
 {	"set",		NULL,			set_cmd,		"[[\"no\"] option]",					"Set or display various session options." },
 {	"simplify",	NULL,			simplify_cmd,		"[\"symbolic\"] [\"quick\"] [\"fraction\"] [equation-number-range]",	"Completely simplify expressions." },
 {	"solve",	NULL,			solve_cmd,		"variable or \"0\"",					"Solve the current equation for a variable or for zero." },
-{	"sum",		NULL,			sum_cmd,		"variable start end [step]",				"Compute the summation as variable goes from start to end." },
+{	"sum",		NULL,			sum_cmd,		"variable start end [step-size]",			"Compute the summation as variable goes from start to end." },
 #if	!LIBRARY
 {	"tally",	NULL,			tally_cmd,		"[\"average\"]",					"Prompt for and add entries, show running (grand) total." },
 #endif
-{	"taylor",	NULL,			taylor_cmd,		"[variable] [order] [point]",				"Compute the Taylor series expansion of the current expression." },
+{	"taylor",	NULL,			taylor_cmd,		"variable order point",					"Compute the Taylor series expansion of the current expression." },
 {	"unfactor",	"expand",		unfactor_cmd,		"[\"fully\"] [equation-number-range]",			"Algebraically expand (multiply out) expressions." },
 #if	!LIBRARY
 {	"variables",	NULL,			variables_cmd,		"[\"c\" or \"java\" or \"integer\"] [equation-number-range]",	"Output all variable names within the specified equations." },
@@ -226,10 +226,10 @@ char	*cp;
 {
 	char	*cp1;
 	char	*cp_start;
-	int	i;
+	int	i, i1;
+	int	len;
 	int	rv;
 	char	buf2[MAX_CMD_LEN];
-	int	i1;
 	char	*filename;
 	FILE	*fp;
 	int	append_flag;
@@ -240,7 +240,8 @@ char	*cp;
 	set_sign_array();
 	cp_start = cp;
 	cp = skip_space(cp);
-	if (*cp == '#') {	/* handle the equation number selector */
+/* handle the equation number selector */
+	if (*cp == '#') {
 		cp++;
 		switch (*cp) {
 		case '+':
@@ -271,7 +272,7 @@ char	*cp;
 		return return_result(cur_equation);
 	}
 #if	!SECURE
-	/* handle shell escape */
+/* handle shell escape */
 	if (*cp == '!') {
 		cp1 = getenv("SHELL");
 		if (cp1 == NULL) {
@@ -283,26 +284,24 @@ char	*cp;
 		}
 		cp = skip_space(cp + 1);
 		rv = shell_out(*cp ? cp : cp1);
-		if (rv) {
-			error(_("System command failed."));
-		}
 		return !rv;
 	}
 #endif
-	/* a quick way to get help */
+/* a quick way to get help */
 	if (*cp == '?') {
 		cp = skip_space(cp + 1);
 		input_column += (cp - cp_start);
 		return(help_cmd(cp));
 	}
-/* See if the string pointed to by "cp" is a command. */
+/* See if the string pointed to by cp is a command. */
 /* If so, execute it. */
 	cp1 = cp;
 	while (*cp1 && !isspace(*cp1))
 		cp1++;
+	len = cp1 - cp;	/* length of possible command name in cp */
 	for (i = 0; i < ARR_CNT(com_list); i++) {
-		if (((cp1 - cp) >= min(4, strlen(com_list[i].name)) && strncasecmp(cp, com_list[i].name, cp1 - cp) == 0)
-		    || (com_list[i].secondary_name && (cp1 - cp) >= min(4, strlen(com_list[i].secondary_name)) && strncasecmp(cp, com_list[i].secondary_name, cp1 - cp) == 0)) {
+		if ((len >= min(4, strlen(com_list[i].name)) && strncasecmp(cp, com_list[i].name, len) == 0)
+		    || (com_list[i].secondary_name && len >= min(4, strlen(com_list[i].secondary_name)) && strncasecmp(cp, com_list[i].secondary_name, len) == 0)) {
 			cp1 = skip_space(cp1);
 			input_column += (cp1 - cp_start);
 			if (my_strlcpy(buf2, cp1, sizeof(buf2)) >= sizeof(buf2)) {
@@ -338,13 +337,8 @@ char	*cp;
 				gfp = fp;
 			}
 #endif
-			/* remove trailing spaces from the command line */
-		        i1 = strlen(buf2) - 1;
-		        while (i1 >= 0 && isspace(buf2[i1])) {
-        		        buf2[i1] = '\0';
-                		i1--;
-			}
-			/* execute the command */
+			remove_trailing_spaces(buf2);
+/* execute the command by calling the command function */
 			rv = (*com_list[i].func)(buf2);
 #if	!SECURE
 			if (fp) {	/* if output redirected, close output file */
@@ -358,7 +352,7 @@ char	*cp;
 			return rv;
 		}
 	}
-/* "cp" is not a command, so parse the expression or equation. */
+/* cp is not a command, so parse the expression or equation */
 	i = next_espace();
 	input_column += (cp - cp_start);
 	return process_parse(i, cp);
@@ -378,6 +372,7 @@ char	*cp;
 
 	reset_attr();
 	rv = system(cp);
+	printf("\n");
 	if (rv < 0) {
 		perror("system(3) call failed");
 	}
@@ -485,26 +480,26 @@ next_argument:
 			P("Commonly Used Geometric Formulas");
 			P("--------------------------------");
 			P("Triangle of base \"b\" and height \"h\":");
-			P("    Area = b*h/2");
+			P("    area = b*h/2");
 			P("Rectangle of length \"l\" and width \"w\":");
-			P("    Area = l*w                    Perimeter = 2*l + 2*w");
+			P("    area = l*w                    perimeter = 2*l + 2*w");
 			P("Trapezoid of parallel sides \"a\" and \"b\", and \"d\" distance between them:");
-			P("    Area = d*(a + b)/2");
+			P("    area = d*(a + b)/2");
 			P("Circle of radius \"r\":");
-			P("    Area = pi*r^2                 Perimeter = 2*pi*r");
-			P("    Area = Perimeter*r/2");
+			P("    area = pi*r^2                 perimeter = 2*pi*r");
+			P("    area = perimeter*r/2");
 			P("Rectangular solid of length \"l\", width \"w\", and height \"h\":");
-			P("    Volume = l*w*h                Surface area = 2*l*w + 2*l*h + 2*w*h");
+			P("    volume = l*w*h                surface_area = 2*l*w + 2*l*h + 2*w*h");
 			P("Sphere of radius \"r\":");
-			P("    Volume = 4/3*pi*r^3           Surface area = 4*pi*r^2");
+			P("    volume = 4/3*pi*r^3           surface_area = 4*pi*r^2");
 			P("Right circular cylinder of radius \"r\" and height \"h\":");
-			P("    Volume = pi*r^2*h             Surface area = 2*pi*r*(h + r)");
+			P("    volume = pi*r^2*h             surface_area = 2*pi*r*(h + r)");
 			P("Right circular cone of radius \"r\" and height \"h\":");
-			P("    Volume = pi*r^2*h/3");
-			P("    Base surface area = pi*r^2    Side surface area = pi*r*(r^2 + h^2)^.5\n");
+			P("    volume = pi*r^2*h/3");
+			P("    base_surface_area = pi*r^2    side_surface_area = pi*r*(r^2 + h^2)^.5\n");
 
 			P("Convex polygon of \"n\" sides, sum of all interior angles formula:");
-			P("    Sum = (n - 2)*180 degrees     Sum = (n - 2)*pi radians");
+			P("    sum = (n - 2)*180 degrees     sum = (n - 2)*pi radians");
 			return true;
 		}
 		if (strncasecmp(cp, "expressions", cp1 - cp) == 0 || strncasecmp(cp, "equations", cp1 - cp) == 0) {
@@ -513,10 +508,9 @@ next_argument:
 			P("    - negate");
 			P("    ! factorial (gamma function)");
 			P("    ** or ^ power (exponentiation)");
-			P("    * multiply        / divide          % modulus");
+			P("    * multiply        / divide          % modulus         // integral divide");
 			P("    + add             - subtract");
-			P("    = equate");
-			P("Operators in the same precedence level are evaluated left to right.\n");
+			P("    = equate\n");
 
 			P("Variables consist of any combination of letters, digits, and underscores (_).");
 			P("Predefined constants and variables follow:");
@@ -524,15 +518,17 @@ next_argument:
 			P("    pi or pi# - the universal constant pi (3.1415926535...).");
 			P("    i or i# - the imaginary number (square root of -1).");
 			P("The above constants may also be used most anywhere variables are required.");
-			P("    sign, sign1, sign2, sign3, ... - variable that can only be +1 or -1.");
-			P("    integer - variable that may be any integer.");
+			P("    sign, sign1, sign2, sign3, ... - variables that can only be +1 or -1.");
 			P("    inf - infinity constant (not a variable).\n");
 
 			P("Absolute value notation \"|x|\" and dual polarity \"+/-\" are understood.");
+			P("Full documentation can be found at http://mathomatic.org/");
 			return true;
 		}
 		if (is_all(cp)) {
-			for (i = 0, row = 1; i < ARR_CNT(com_list); i++) {
+			P("Mathomatic Command Summary");
+			P("--------------------------");
+			for (i = 0, row = 3; i < ARR_CNT(com_list); i++) {
 				row += display_command(i);
 				if (gfp == stdout && screen_rows && row >= (screen_rows - 5)) {
 					row = 1;
@@ -541,16 +537,18 @@ next_argument:
 					printf("\n");
 				}
 			}
-			P("End of command list.");
+			P("Full documentation can be found at http://mathomatic.org/");
 			return true;
 		}
+		error(_("Unrecognized help topic or command."));
+		return false;
 	}
 	/* default help text: */
 	P("This help command is provided as a quick reference.");
-	P("Full documentation is available at the website \"www.mathomatic.org\".");
-	P("Type \"help all\" for a summary and syntax of the all commands.");
-	P("Type \"help usage\" for syntax of all commands.");
-	P("Type \"help expressions\" for help with entering expressions.");
+	P("Full documentation can be found at http://mathomatic.org/");
+	P("Type \"help all\" for a summary and syntax of all commands.");
+	P("Type \"help usage\" to display the syntax of all commands.");
+	P("Type \"help equations\" for help with entering expressions and equations.");
 	P("Type \"help geometry\" for some commonly used geometric formulas.");
 	P("\"help\" or \"?\" followed by command names will give info on those commands.\n");
 
@@ -563,7 +561,7 @@ next_argument:
 			fprintf(gfp, " ");
 	}
 
-	P("\n\nTo select an equation in memory, type the equation number at the main prompt.");
+	P("\n\nTo select an equation space, type the equation number at the main prompt.");
 	P("To solve the current equation, type the variable name at the main prompt.");
 	return true;
 }
