@@ -1,12 +1,12 @@
 /*
- * This file contains the C library functions for the Mathomatic library.
+ * This file contains the C functions for the Mathomatic API.
  * Refer to this, if you are going to use the Mathomatic code in other projects.
  *
  * Be sure and define "LIBRARY" when compiling the Mathomatic code for this.
  * And be sure to call "clear_all()" after completing each group of operations,
  * otherwise the equation spaces will fill up.
  *
- * Mathomatic Copyright (C) 1987-2007 George Gesslein II.
+ * Written by George Gesslein II.
  */
 
 #include "../includes.h"
@@ -130,5 +130,5 @@ matho_parse(char *input, char **outputp)
 void
 fphandler(int sig)
 {
-        error(_("Floating point exception."));
+/*	error(_("Floating point exception.")); */
 }
