@@ -1,11 +1,11 @@
 /*
- * This file contains a test for the Mathomatic symbolic math library.
+ * This file contains a test for the Mathomatic symbolic math library and API.
  * Refer to this, if you are going to use the Mathomatic code in other projects.
  *
  * To run this, compile and link with the Mathomatic symbolic math library
  * and create an executable.
  *
- * Mathomatic Copyright (C) 1987-2006 George Gesslein II.
+ * Written by George Gesslein II.
  */
 
 #include <stdio.h>
@@ -19,6 +19,7 @@ main(int argc, char **argv)
 	int	rv;
 	char	buf[1000];
 
+	printf("Mathomatic library test program.\n");
 	if (!matho_init()) {
 		fprintf(stderr, "Not enough memory.\n");
 		exit(1);
@@ -26,7 +27,7 @@ main(int argc, char **argv)
 	/* Mathomatic is ready for use. */
 	/* This is an input/output loop for testing. */
 	for (;;) {
-		printf("-> ");
+		printf("%d-> ", cur_equation + 1);
 		if ((cp = fgets(buf, sizeof(buf), stdin)) == NULL)
 			break;
 		rv = matho_process(cp, &ocp);
