@@ -30,8 +30,8 @@ static int	carray[] = {
 static char	*html_carray[] = {
 	"#00FF00",	/* bright green (default color) */
 	"#FFFF00",
-	"#FF9000",
 	"#FF0000",
+	"#FF9000",
 	"#FF00FF",
 	"#00FFFF",
 	"#0000FF"
@@ -105,7 +105,7 @@ default_color()
 int
 list1_sub(n, export_flag)
 int	n;		/* equation space number */
-int	export_flag;	/* true for exportable format (readable by other math programs) */
+int	export_flag;	/* non-zero for exportable format (readable by other math programs) */
 			/* 1 for Maxima, 2 for other */
 {
 	int	len = 0;
@@ -123,9 +123,9 @@ int	export_flag;	/* true for exportable format (readable by other math programs)
 	if (export_flag == 1) {
 		len += fprintf(gfp, ";");
 	}
-	if (high_prec) {
+	if (high_prec || export_flag) {
 #if	CYGWIN
-		fprintf(gfp, "\r\n");
+		fprintf(gfp, "\r\n");	/* might be redirecting to a Microsoft text file */
 #else
 		fprintf(gfp, "\n");
 #endif
@@ -369,11 +369,18 @@ int		export_flag;	/* flag for exportable format (usually false) */
 			case DIVIDE:
 				cp = "/";
 				break;
+			case IDIVIDE:
+				cp = "//";
+				break;
 			case MODULUS:
 				cp = MODULUS_STRING;
 				break;
 			case POWER:
-				cp = "^";
+				if (power_starstar) {
+					cp = "**";
+				} else {
+					cp = "^";
+				}
 				break;
 			case FACTORIAL:
 				cp = "!";
@@ -533,11 +540,18 @@ int		export_flag;
 			case DIVIDE:
 				cp = "/";
 				break;
+			case IDIVIDE:
+				cp = "//";
+				break;
 			case MODULUS:
 				cp = MODULUS_STRING;
 				break;
 			case POWER:
-				cp = "^";
+				if (power_starstar) {
+					cp = "**";
+				} else {
+					cp = "^";
+				}
 				break;
 			case FACTORIAL:
 				cp = "!";
@@ -576,24 +590,29 @@ int		n;		/* length of expression */
 
 /*
  * Display an equation as C, Java, or Python code.
+ *
+ * Return length of output (number of characters).
  */
-void
+int
 list_c_equation(en, language, int_flag)
 int	en;		/* equation space number */
 int	language;
 int	int_flag;	/* integer arithmetic flag */
 {
+	int	len = 0;
+
 	if (n_lhs[en] <= 0)
-		return;
-	list_code(lhs[en], &n_lhs[en], language, int_flag);
+		return 0;
+	len += list_code(lhs[en], &n_lhs[en], language, int_flag);
 	if (n_rhs[en]) {
-		fprintf(gfp, " = ");
-		list_code(rhs[en], &n_rhs[en], language, int_flag);
+		len += fprintf(gfp, " = ");
+		len += list_code(rhs[en], &n_rhs[en], language, int_flag);
 	}
 	if (language != 2) {
-		fprintf(gfp, ";");
+		len += fprintf(gfp, ";");
 	}
 	fprintf(gfp, "\n");
+	return len;
 }
 
 /*
@@ -700,6 +719,7 @@ int		int_flag;	/* integer arithmetic flag, should work with any language */
 				cp = "*";
 				break;
 			case DIVIDE:
+			case IDIVIDE:
 				cp = "/";
 				break;
 			case MODULUS:
@@ -1013,13 +1033,22 @@ check_again:
 				cp = "/";
 				len++;
 				break;
+			case IDIVIDE:
+				cp = "//";
+				len += 2;
+				break;
 			case MODULUS:
 				cp = MODULUS_STRING;
 				len += strlen(cp);
 				break;
 			case POWER:
-				cp = "^";
-				len++;
+				if (power_starstar) {
+					cp = "**";
+					len += 2;
+				} else {
+					cp = "^";
+					len++;
+				}
 				break;
 			case FACTORIAL:
 				cp = "!";
