@@ -41,6 +41,8 @@
 static void usage();
 static int set_signals();
 
+static char	rc_file[MAX_CMD_LEN];
+
 int
 main(argc, argv)
 int	argc;
@@ -72,7 +74,6 @@ char	**argv;
 			coption++;
 			break;
 		case 'h':
-			readline_enabled = false;
 			html_flag = true;
 			break;
 		case 'm':
@@ -130,16 +131,15 @@ char	**argv;
 #if	!SECURE
 	/* read the user options initialization file */
 	if (!test_mode && !load_rc()) {
-		fprintf(stderr, _("%s: Error loading set options from \"%s\".\n"), prog_name, RC_FILE);
+		fprintf(stderr, _("%s: Error loading set options from \"%s\".\n"), prog_name, rc_file);
 	}
 #endif
 	if (test_mode) {
 		color_flag = false;
-	}
-	if (coption & 1) {
+	} else if (coption & 1) {
 		color_flag = !color_flag;
 	}
-	if (!test_mode && !quiet_mode && color_flag) {
+	if (!quiet_mode && color_flag) {
 		printf(_("%s color mode enabled.\n"), html_flag ? "HTML" : "ANSI");
 	}
 	if ((i = setjmp(jmp_save)) != 0) {
@@ -192,7 +192,7 @@ usage()
 	fprintf(stderr, "Usage: %s [ options ] [ input_files ]\n\n", prog_name);
 	fprintf(stderr, "Options:\n");
 	fprintf(stderr, "  -c            Toggle color mode.\n");
-	fprintf(stderr, "  -h            Enable HTML output mode and disable readline.\n");
+	fprintf(stderr, "  -h            Enable HTML output mode.\n");
 	fprintf(stderr, "  -m number     Specify a memory size multiplier.\n");
 	fprintf(stderr, "  -q            Set quiet mode (don't display prompts).\n");
 	fprintf(stderr, "  -r            Disable readline.\n");
@@ -258,26 +258,26 @@ char	*cp;
 int
 load_rc()
 {
-	FILE	*fp;
+	FILE	*fp = NULL;
 	char	buf[MAX_CMD_LEN];
 	char	*cp;
 	int	rv = true;
 
+	cp = getenv("HOME");
+	if (cp) {
+		snprintf(rc_file, sizeof(rc_file), "%s/%s", cp, ".mathomaticrc");
+		fp = fopen(rc_file, "r");
+	}
 #if	CYGWIN
-	snprintf(buf, sizeof(buf), "%s/%s", dir_path, RC_FILE);
-	fp = fopen(buf, "r");
 	if (fp == NULL) {
+		snprintf(rc_file, sizeof(rc_file), "%s/%s", dir_path, "mathomatic.rc");
+		fp = fopen(rc_file, "r");
+	}
+#endif
+	if (fp == NULL) {
+		rc_file[0] = '\0';
 		return true;
 	}
-#else
-	cp = getenv("HOME");
-	if (cp == NULL)
-		return true;
-	snprintf(buf, sizeof(buf), "%s/%s", cp, RC_FILE);
-	fp = fopen(buf, "r");
-	if (fp == NULL)
-		return true;
-#endif
 	while ((cp = fgets(buf, sizeof(buf), fp)) != NULL) {
 		set_error_level(cp);
 		if (!set_options(cp))
@@ -301,18 +301,27 @@ int	sig;
 
 /*
  * Control-C (interrupt) handler.
+ * Interrupts processing and returns to main prompt through a polling mechanism.
+ * If it can't, repeated calls terminate this program.
  */
 void
 inthandler(sig)
 int	sig;
 {
-#if	true
-	abort_flag = true;	/* interrupt processing and return to main prompt */
-#else
-	/* Abruptly quit this program. */
-	printf(_("\nControl-C pressed, quitting...\n"));
-	exit_program(1);
-#endif
+	abort_flag++;
+	switch (abort_flag) {
+	case 0:
+	case 1:
+		/* wait for graceful abort */
+		return;
+	case 2:
+		printf(_("\nPress Control-C once more to quit program.\n"));
+		break;
+	default:
+		/* abruptly quit this program */
+		printf(_("\nControl-C repeatedly pressed, quitting...\n"));
+		exit_program(1);
+	}
 }
 
 /*
