@@ -66,10 +66,12 @@ int		i;	/* location of operator to parenthesize in expression */
 	int	j;
 	int	level;
 
+#if	false
 	if (i >= (n - 1) || (n & 1) != 1 || (i & 1) != 1) {
 		error("Internal error in arguments to binary_parenthesize().");
 		longjmp(jmp_save, 13);
 	}
+#endif
 	level = p1[i].level++;
 	if (p1[i-1].level++ > level) {
 		for (j = i - 2; j >= 0; j--) {
@@ -88,7 +90,8 @@ int		i;	/* location of operator to parenthesize in expression */
 }
 
 /*
- * Handle and remove the special NEGATE operator.
+ * Handle and remove the special high priority NEGATE operator.
+ * To make negate the same priority as times/divide, don't parenthesize here.
  */
 void
 handle_negate(equation, np)
@@ -99,8 +102,11 @@ int		*np;
 
 	for (i = 1; i < *np; i += 2) {
 		if (equation[i].token.operatr == NEGATE) {
+			/* change negate operator to -1 times the operand: */
 			equation[i].token.operatr = TIMES;
+			/* make negate top priority by parenthesizing it first: */
 			binary_parenthesize(equation, *np, i);
+			/* comment out the above line to make negate the same priority as times/divide */
 		}
 	}
 }
@@ -144,6 +150,7 @@ int		*np;		/* pointer to expression length */
 		case TIMES:
 		case DIVIDE:
 		case MODULUS:
+		case IDIVIDE:
 			binary_parenthesize(equation, *np, i);
 			break;
 		}
@@ -275,8 +282,8 @@ char		*cp;		/* string to parse */
 			if (operand) {
 				goto syntax_error;
 			}
-			if (cp[1] == '!') {
-				debug_string(0, _("Multifactorial not implemented, use \"(x!)!\" for the factorial of x factorial."));
+			if (cp[1] == '!' && cp[2] != '!') {
+				warning(_("Multifactorial not implemented, use \"(x!)!\" for the factorial of x factorial."));
 			}
 			equation[n].level = cur_level;
 			equation[n].kind = OPERATOR;
@@ -315,9 +322,16 @@ parse_power:
 			if (operand) {
 				goto syntax_error;
 			}
-			equation[n].level = cur_level;
-			equation[n].kind = OPERATOR;
-			equation[n].token.operatr = DIVIDE;
+			if (cp[1] == '/') {
+				cp++;
+				equation[n].level = cur_level;
+				equation[n].kind = OPERATOR;
+				equation[n].token.operatr = IDIVIDE;
+			} else {
+				equation[n].level = cur_level;
+				equation[n].kind = OPERATOR;
+				equation[n].token.operatr = DIVIDE;
+			}
 			n++;
 			break;
 		case '%':
@@ -386,14 +400,14 @@ parse_power:
 			cp1 = cp;
 			errno = 0;
 			d = strtod(cp1, &cp);
-			if (errno) {
-				put_up_arrow((int) (cp1 - cp_start), _("Constant out of range."));
-				return(NULL);
-			}
 			if (cp == cp1) {
 				put_up_arrow((int) (cp1 - cp_start), _("Error parsing constant."));
 				return(NULL);
 			}
+			if (errno) {
+				put_up_arrow((int) (cp1 - cp_start), _("Constant out of range."));
+				return(NULL);
+			}
 			equation[n].kind = CONSTANT;
 			equation[n].token.constant = d;
 			equation[n].level = cur_level;
@@ -439,7 +453,7 @@ p_out:
 		put_up_arrow((int) (cp - cp_start), _("Unmatched parentheses: missing )."));
 		return(NULL);
 	}
-	if (*cp == '=')
+	while (*cp == '=')
 		cp++;
 	*np = n;
 	if (n) {
@@ -581,6 +595,22 @@ char	*cp;
 	return cp1;
 }
 
+/*
+ * Remove trailing spaces from a string.
+ */
+void
+remove_trailing_spaces(cp)
+char	*cp;
+{
+	int	i;
+
+	i = strlen(cp) - 1;
+	while (i >= 0 && isspace(cp[i])) {
+		cp[i] = '\0';
+		i--;
+	}
+}
+
 /*
  * This should be called for all line input.
  * Set point_flag to true if pointing to the input error will work for the passed string.
@@ -593,23 +623,14 @@ char	*cp;	/* input string */
 	char	*cp1;
 
 	point_flag = true;
-/* handle comments and the DOS EOF character (control-Z) by truncating the string where found */
+/* handle comments, newlines, and the DOS EOF character (control-Z) by truncating the string where found */
 	for (cp1 = cp; *cp1; cp1++) {
-		if (*cp1 == ';' || *cp1 == '\032') {
+		if (*cp1 == ';' || *cp1 == '\n' || *cp1 == '\r' || *cp1 == '\032') {
 			*cp1 = '\0';
 			break;
 		}
 	}
-/* remove trailing newlines, carriage returns, and spaces */
-	cp1 = &cp[strlen(cp)];
-	while (cp1 > cp) {
-		cp1--;
-		if (*cp1 == '\n' || *cp1 == '\r' || isspace(*cp1)) {
-			*cp1 = '\0';
-		} else {
-			break;
-		}
-	}
+	remove_trailing_spaces(cp);
 /* set point_flag to false if non-printable characters encountered */
 	for (cp1 = cp; *cp1; cp1++) {
 		if (!isprint(*cp1)) {
