@@ -1,7 +1,7 @@
 /*
  * Mathomatic simplifying and polynomial routines.
  * Includes polynomial and smart division, polynomial factoring, etc.
- * tlhs and trhs are wiped out by most of these routines.
+ * Globals tlhs[] and trhs[] are wiped out by most of these routines.
  *
  * The polynomial division and GCD routines here are not recursive, due to static
  * storage areas.  This limits the polynomial GCD to univariate operation.
@@ -44,7 +44,7 @@ sort_type	*p1, *p2;
  * Return true if passed expression is strictly a single polynomial term in variable v.
  * The exponent may be anything, as long as it doesn't contain the variable.
  */
-static inline int
+static int
 poly_in_v_sub(p1, n, v, allow_divides)
 token_type	*p1;		/* expression pointer */
 int		n;		/* expression length */
@@ -122,7 +122,7 @@ int		allow_divides;	/* allow variable to be right of a divide (negative exponent
 }
 
 /*
- * Factor polynomials.
+ * Factor polynomials by calling pf_sub() for every additive subexpression.
  * Factors repeated factor polynomials (like (x+1)^5)
  * and symbolic factor polynomials (like (x+a)*(x+b)).
  *
@@ -207,8 +207,8 @@ int		*np, loc, len, level;
 	blt(save_save, jmp_save, sizeof(jmp_save));
 	if ((i = setjmp(jmp_save)) != 0) {	/* trap errors */
 		blt(jmp_save, save_save, sizeof(jmp_save));
-		if (i == 13) {
-			longjmp(jmp_save, 13);
+		if (i == 13) {	/* critical error code */
+			longjmp(jmp_save, i);
 		}
 		return(modified || symbolic_modified);
 	}
@@ -421,9 +421,9 @@ int		*np, loc1, len, level;
 }
 
 /*
- * Remove level 1 trivial factors and divides from "tlhs".
+ * Remove level 1 trivial factors and divides from tlhs.
  *
- * Return true if result is a level 1 plus type expression.
+ * Return true if result is a level 1 additive expression.
  * If this returns false, nothing is removed.
  */
 int
@@ -502,7 +502,7 @@ long		*vp;
 	int	i;
 	int	count;
 
-	for (count = 1;; count++) {
+	for (count = 1; count < 50; count++) {
 		switch (poly_div(trhs, n_trhs, gcd_divisor, len_d, vp)) {
 		case 0:
 			/* divide failed */
@@ -521,14 +521,15 @@ long		*vp;
 		n_trhs = len_d;
 		len_d = i;
 	}
+	return 0;
 }
 
 /*
  * Compute polynomial Greatest Common Divisor of "larger" and "smaller".
  *
  * Return true if successful.
- * Return the GCD in "trhs".
- * Return "larger"/GCD in "tlhs".
+ * Return the GCD in trhs[].
+ * Return larger/GCD in tlhs[].
  */
 int
 poly_gcd(larger, llen, smaller, slen, v)
@@ -566,7 +567,7 @@ long		v;
 		blt(gcd_divisor, tlhs, n_tlhs * sizeof(token_type));
 		len_d = n_tlhs;
 		if (poly_div(larger, llen, gcd_divisor, len_d, &v) != 2) {
-			debug_string(0, "Polynomial GCD found, but larger divide failed.");
+			warning("Polynomial GCD found, but larger divide failed.");
 			return 0;
 		}
 	}
@@ -584,8 +585,8 @@ long		v;
  * Compute polynomial Greatest Common Divisor of "larger" and "smaller".
  *
  * Return true if successful.
- * Return "larger"/GCD in "tlhs".
- * Return "smaller"/GCD in "trhs".
+ * Return larger/GCD in tlhs[].
+ * Return smaller/GCD in trhs[].
  */
 int
 poly2_gcd(larger, llen, smaller, slen, v)
@@ -607,16 +608,18 @@ long		v;
 	n_trhs = llen;
 	blt(tlhs, smaller, slen * sizeof(token_type));
 	n_tlhs = slen;
+#if	true
 	blt(save_save, jmp_save, sizeof(jmp_save));
 	if ((i = setjmp(jmp_save)) != 0) {	/* trap errors */
 		blt(jmp_save, save_save, sizeof(jmp_save));
-		if (i == 13) {
-			longjmp(jmp_save, 13);
+		if (i == 13) {	/* critical error code */
+			longjmp(jmp_save, i);
 		}
 		return 0;
 	}
 	uf_simp(tlhs, &n_tlhs);
 	blt(jmp_save, save_save, sizeof(jmp_save));
+#endif
 	if (!level1_plus_count(tlhs, n_tlhs))
 		return 0;
 	if (n_tlhs > ARR_CNT(gcd_divisor))
@@ -630,7 +633,7 @@ long		v;
 		if (!level1_plus_count(gcd_divisor, len_d))
 			return 0;
 		if (poly_div(smaller, slen, gcd_divisor, len_d, &v) != 2) {
-			debug_string(0, "Polynomial GCD found, but smaller divide failed.");
+			warning("Polynomial GCD found, but smaller divide failed.");
 			return 0;
 		}
 		blt(trhs, gcd_divisor, len_d * sizeof(token_type));
@@ -642,7 +645,7 @@ long		v;
 		blt(tlhs, trhs, n_trhs * sizeof(token_type));
 		n_tlhs = n_trhs;
 		if (poly_div(larger, llen, tlhs, n_tlhs, &v) != 2) {
-			debug_string(0, "Polynomial GCD found, but larger divide failed.");
+			warning("Polynomial GCD found, but larger divide failed.");
 			return 0;
 		}
 		blt(trhs, gcd_divisor, len_d * sizeof(token_type));
@@ -1140,10 +1143,9 @@ next_thingy:
  * Do polynomial division.
  *
  * Returns non-zero if successful, 2 if remainder is 0.
- * Quotient is returned in "tlhs" and remainder in "trhs".
+ * Quotient is returned in tlhs[] and remainder in trhs[].
  *
- * If "*vp" is 0, automatically select the best base variable,
- * and return it in "*vp".
+ * If *vp is 0, automatically select the best base variable and return it in *vp.
  */
 int
 poly_div(d1, len1, d2, len2, vp)
@@ -1163,8 +1165,8 @@ long		*vp;		/* variable pointer to base variable */
 	if ((i = setjmp(jmp_save)) != 0) {	/* trap errors */
 		blt(jmp_save, save_save, sizeof(jmp_save));
 		partial_flag = old_partial;
-		if (i == 13) {
-			longjmp(jmp_save, 13);
+		if (i == 13) {	/* critical error code */
+			longjmp(jmp_save, i);
 		}
 		return false;
 	}
@@ -1175,7 +1177,7 @@ long		*vp;		/* variable pointer to base variable */
 }
 
 /*
- * Do the actual polynomial division.
+ * Do the actual polynomial division using a simple generalized polynomial long division algorithm.
  */
 static int
 poly_div_sub(d1, len1, d2, len2, vp)
@@ -1361,7 +1363,7 @@ long		*vp;
  * of variables, not including any terms with no variables.
  *
  * Returns true if successful.
- * Quotient is returned in "tlhs" and remainder in "trhs".
+ * Quotient is returned in tlhs[] and remainder in trhs[].
  */
 int
 smart_div(d1, len1, d2, len2)
