@@ -21,13 +21,14 @@ Generate batches of consecutive prime numbers up to 19 digits.
 Options:
   -t               Output only twin primes.
   -p base          Output only palindromic primes.
- */
+*/
 
 /*
  * Changes:
  *
- * 11/22/05 - converted everything to long doubles.
+ * 11/22/05 - converted everything to long doubles.  Now uses C99 long double functions.
  * 3/25/06 - made primes buffer variable size.
+ * 3/30/08 - Allow long double to be aliased to double when long double isn't supported.
  */
 
 #include <stdio.h>
@@ -45,32 +46,33 @@ Options:
 #define	false	0
 
 #ifndef	max
-#define max(a, b)    (((a) > (b)) ? (a) : (b))
+#define max(a, b)    (((a) > (b)) ? (a) : (b))		/* return the maximum of two values */
 #endif
 
 #ifndef	min
-#define min(a, b)    (((a) < (b)) ? (a) : (b))
+#define min(a, b)    (((a) < (b)) ? (a) : (b))		/* return the minimum of two values */
 #endif
 
 #define	ARR_CNT(a)	((int) (sizeof(a)/sizeof(a[0])))	/* returns the number of elements in an array */
 
-#define	MAX_K_INTEGER	1.0e19L		/* 19 digits for long doubles */
-
 /* Maximum memory usage in bytes; can be set to any size; the larger, the faster: */
 #define BUFFER_SIZE	2000000
 #if	BUFFER_SIZE >= (INT_MAX / 2) || BUFFER_SIZE <= 0
 #error	"BUFFER_SIZE too large."
 #endif
 
-void	generate_primes(void);
-int	test_pal(long double d, long double base);
-void	usage(void);
-void	usage2(void);
-int	get_long_double_int(char *cp, long double *dp);
+void		generate_primes(void);
+int		test_pal(long double d, long double base);
+void		usage(void);
+void		usage2(void);
+int		get_long_double_int(char *cp, long double *dp);
+long double	ceill(), sqrtl(), fmodl(), strtold();
 
-long double strtold(const char *nptr, char **endptr);
-
-long double start_value, number, end_value;
+long double max_integer;		/* largest value of a long double integral value */
+long double start_value;		/* where to start finding primes */
+long double number;			/* number of primes to display */
+long double default_number = 40;	/* default number of primes to display */
+long double end_value;			/* where to stop finding primes */
 long double skip_multiples[] = {	/* Additive array that skips over multiples of 2, 3, 5, and 7. */
 	10, 2, 4, 2, 4, 6, 2, 6,
 	 4, 2, 4, 6, 6, 2, 6, 4,
@@ -85,10 +87,10 @@ long double	last_prime = -3.0;
 int		pal_flag, twin_flag;
 long double	pal_base = 10;
 
-int	buffer_size = BUFFER_SIZE;	/* for variable size prime buffer */
-char	*prime;				/* the boolean sieve array for the current window of numbers */
+char		*prime;				/* the boolean sieve array for the current window of numbers */
+int		buffer_size;			/* for variable size prime[] buffer */
 
-char	*prog_name = "matho-primes";
+char		*prog_name = "matho-primes";
 
 int
 main(int argc, char *argv[])
@@ -101,12 +103,21 @@ main(int argc, char *argv[])
 
         prog_name = strdup(basename(argv[0]));
 	start_value = -1.0;
-	end_value = MAX_K_INTEGER;
+/* set the highest number this program will work with: */
+	if (sizeof(long double) >= 12) {
+		max_integer = 1.0e19L;	/* 19 digits for long doubles */
+	} else if (sizeof(long double) == 8) {
+		max_integer = 1.0e14L;	/* 14 digits for doubles */
+	} else {
+		fprintf(stderr, "%s: Unsupported size of long double = %d bytes.\n", prog_name, sizeof(long double));
+		exit(2);
+	}
+	end_value = max_integer;
 	if (end_value == end_value + 1.0) {
-		fprintf(stderr, "MAX_K_INTEGER is too large!\n");
+		fprintf(stderr, "Warning: max_integer is too large; size of long double = %d bytes.\n", sizeof(long double));
 	}
 	number = 0;
-	/* process command line options */
+/* process command line options: */
 	while ((i = getopt(argc, argv, "tp:")) >= 0) {
 		switch (i) {
 		case 't':
@@ -141,7 +152,7 @@ main(int argc, char *argv[])
 					usage();
 				}
 				optind++;
-				number = MAX_K_INTEGER;
+				number = max_integer;
 			} else {
 				usage();
 			}
@@ -176,7 +187,7 @@ main(int argc, char *argv[])
 	}
 	if (start_value < 0.0) {
 get1:
-		fprintf(stderr, "Enter number (up to 19 digits) to start finding primes at (0): ");
+		fprintf(stderr, "Enter number to start finding primes at (0): ");
 		if (fgets(buf, sizeof(buf), stdin) == NULL)
 			exit(1);
 		switch (buf[0]) {
@@ -193,14 +204,14 @@ get1:
 	}
 	if (number == 0) {
 get2:
-		fprintf(stderr, "Enter number of primes to output (40): ");
+		fprintf(stderr, "Enter number of primes to output (%Lg): ", default_number);
 		if (fgets(buf, sizeof(buf), stdin) == NULL)
 			exit(1);
 		switch (buf[0]) {
 		case '\0':
 		case '\n':
 		case '\r':
-			number = 40;
+			number = default_number;
 			break;
 		default:
 			if (!get_long_double_int(buf, &number)) {
@@ -208,6 +219,7 @@ get2:
 			}
 		}
 	}
+/* allocate the prime[] buffer: */
 	buffer_size = (int) min(BUFFER_SIZE, (end_value - start_value) + 1.0L);
 	prime = (char *) malloc(buffer_size);
 	if (prime == NULL) {
@@ -221,7 +233,7 @@ get2:
 /*
  * Eliminate all multiples of "arg" from the sieve array by setting their entries to false.
  */
-inline void
+void
 elim_factor(long double arg)
 {
 	long double	d;
@@ -259,7 +271,7 @@ generate_primes()
 		if (start_value > end_value) {
 			return;
 		}
-		/* do the prime number sieve */
+		/* generate a batch of consecutive primes with the prime number sieve */
 		memset(prime, true, buffer_size);	/* set the prime array to all true */
 		vv = 1.0 + sqrtl(min(start_value + (long double) buffer_size, end_value));
 		elim_factor(2.0L);
@@ -275,7 +287,7 @@ generate_primes()
 			if (ii > vv)
 				break;
 		}
-		/* display the batch of generated prime numbers */
+		/* display the requested part of the batch of generated prime numbers */
 		for (n = 0; n < buffer_size && count < number; n++) {
 			if (prime[n]) {
 				ii = start_value + n;
@@ -328,7 +340,7 @@ get_long_double_int(char *cp, long double *dp)
 		fprintf(stderr, "Invalid number.\n");
 		return false;
 	}
-	if (*dp > MAX_K_INTEGER) {
+	if (*dp > max_integer) {
 		fprintf(stderr, "Number is too large.\n");
 		return false;
 	}
@@ -368,7 +380,7 @@ void
 usage()
 {
 	fprintf(stderr, "\nUsage: %s [start [stop]] [\"twin\"] [\"pal\" [base]]\n\n", prog_name);
-	fprintf(stderr, "Generate batches of consecutive prime numbers up to 19 digits.\n");
+	fprintf(stderr, "Generate batches of consecutive prime numbers up to %Lg.\n", max_integer);
 	fprintf(stderr, "If \"twin\" is specified, output only twin primes.\n");
 	fprintf(stderr, "If \"pal\" is specified, output only palindromic primes.\n");
 	fprintf(stderr, "The palindromic base may be specified, the default is base 10.\n");
@@ -379,7 +391,7 @@ void
 usage2()
 {
 	fprintf(stderr, "\nUsage: %s [options] [start [stop]]\n\n", prog_name);
-	fprintf(stderr, "Generate batches of consecutive prime numbers up to 19 digits.\n");
+	fprintf(stderr, "Generate batches of consecutive prime numbers up to %Lg.\n", max_integer);
 	fprintf(stderr, "Options:\n");
 	fprintf(stderr, "  -t               Output only twin primes.\n");
 	fprintf(stderr, "  -p base          Output only palindromic primes.\n");
