@@ -196,7 +196,7 @@ int		*np;
  * Applies many equivalent algebraic transformations and their inverses (like unfactor and factor),
  * then does generalized polynomial simplifications.
  *
- * tlhs and trhs are wiped out.
+ * Globals tlhs[] and trhs[] are wiped out.
  */
 void
 simpa_side(equation, np, quick_flag, frac_flag)
@@ -262,8 +262,8 @@ do_quick:
 		blt(save_save, jmp_save, sizeof(jmp_save));
 		if ((i = setjmp(jmp_save)) != 0) {	/* trap errors */
 			blt(jmp_save, save_save, sizeof(jmp_save));
-			if (i == 13) {
-				longjmp(jmp_save, 13);
+			if (i == 13) {	/* critical error code */
+				longjmp(jmp_save, i);
 			}
 			/* an error occurred, restore the original expression */
 			*np = n_tlhs;
@@ -307,7 +307,9 @@ do_quick:
 	unsimp_power(equation, np);
 	make_fractions(equation, np);
 	factor_power(equation, np);
+	partial_flag = frac_flag;
 	uf_tsimp(equation, np);
+	partial_flag = true;
 	make_fractions(equation, np);
 	uf_power(equation, np);
 	integer_root_simp(equation, np);
@@ -784,7 +786,7 @@ int		*np;
 	return modified;
 }
 
-static inline int
+static int
 sp2_sub(equation, np, i)
 token_type	*equation;
 int		*np, i;
@@ -845,7 +847,7 @@ int		*np;
 	return modified;
 }
 
-static inline int
+static int
 sp_sub(equation, np, i)
 token_type	*equation;
 int		*np, i;
@@ -940,7 +942,7 @@ int		iflag;		/* produce imaginary numbers flag */
  *
  * Return true if successful.
  */
-static inline int
+static int
 calc(op1p, k1p, op2, k2)
 int	*op1p;	/* pointer to operator 1, sometimes modified */
 double	*k1p;	/* pointer to operand 1 and where to store the result */
@@ -995,9 +997,12 @@ double	k2;	/* operand 2 */
 			}
 		}
 		break;
+	case IDIVIDE:
+		modf(*k1p / k2, k1p);
+		break;
 	case MODULUS:
 		if (k2 == 0) {
-			debug_string(0, _("Warning: modulo 0 encountered, might be considered undefined."));
+			warning(_("Modulo 0 encountered, might be considered undefined."));
 		}
 #if	false	/* If fmod() always works.  It doesn't. */
 		*k1p = fmod(*k1p, k2);
@@ -1014,12 +1019,12 @@ double	k2;	/* operand 2 */
 			break;
 		}
 		if (*k1p == 0.0 && k2 < 0.0) {
-			error(_("Divide by zero error."));
+			error(_("Divide by zero error (0 raised to negative power)."));
 			longjmp(jmp_save, 2);
 		}
 		domain_check = true;
 		if (*k1p == 0.0 && k2 == 0.0) {
-			debug_string(0, _("Warning: 0^0 encountered, might be considered undefined."));
+			warning(_("0^0 encountered, might be considered undefined."));
 			d = 1.0;	/* some people don't know 0^0 */
 		} else {
 			d = pow(*k1p, k2);
@@ -1390,6 +1395,7 @@ int		*np;		/* pointer to length of equation side */
 			}
 			break;
 		case MODULUS:
+		case IDIVIDE:
 			if (p2->level == level && p2->kind == CONSTANT && p2->token.constant == 0.0) {
 /* Replace 0%x with 0. */
 				for (p2 = p1 + 2; p2 < ep; p2 += 2) {
@@ -1945,7 +1951,7 @@ int		*np;
 	return(order_recurse(equation, np, 0, 1));
 }
 
-static inline void
+static void
 swap(equation, np, level, i1, i2)
 token_type	*equation;
 int		*np;
