@@ -1,7 +1,7 @@
 /*
- * Mathomatic solve routines.
+ * Mathomatic symbolic solve routines.
  *
- * Copyright (C) 1987-2007 George Gesslein II.
+ * Copyright (C) 1987-2008 George Gesslein II.
  */
 
 #include "includes.h"
@@ -100,6 +100,10 @@ int		*rightnp;	/* size of RHS */
 	}
 	if (wantp->kind == VARIABLE) {
 		v = wantp->token.variable;
+		if (v == 0) {
+			error(_("Solve variable is null!"));
+			return false;
+		}
 		if (!found_var(trhs, n_trhs, v) && !found_var(tlhs, n_tlhs, v)) {
 			error(_("Variable not found."));
 			return false;
@@ -196,84 +200,77 @@ left_again:
 	worked = true;
 	uf_flag = false;
 see_work:
+	if (found_var(trhs, n_trhs, v)) {
+		/* solve variable in RHS */
+		debug_string(1, _("Solve variable moved back to RHS, quitting solve routine."));
+		return false;
+	}
 	/* See if we have solved the equation. */
-	if (se_compare(wantp, wantn, tlhs, n_tlhs, &diff_sign)) {
-		if (!diff_sign) {
-			if (!zsolve) {
-				ep = &trhs[n_trhs];
-				for (p1 = trhs; p1 < ep; p1 += 2) {
-					if (p1->kind == VARIABLE && p1->token.variable == v) {
-						return false;
+	if (se_compare(wantp, wantn, tlhs, n_tlhs, &diff_sign) && !diff_sign) {
+		if (zsolve) {
+zero_simp:
+			list_tdebug(4);
+			uf_power(trhs, &n_trhs);
+			do {
+				do {
+					simp_ssub(trhs, &n_trhs, 0L, 0.0, false, true, 0);
+				} while (uf_power(trhs, &n_trhs));
+			} while (super_factor(trhs, &n_trhs, 1));
+			list_tdebug(3);
+			ep = &trhs[n_trhs];
+			op = 0;
+			for (p1 = trhs + 1; p1 < ep; p1 += 2) {
+				if (p1->level == 1) {
+					op = p1->token.operatr;
+					if (op == DIVIDE) {
+						goto no_simp;
+					}
+					if (op != TIMES) {
+						break;
 					}
 				}
-			} else {
-zero_simp:
-				list_tdebug(4);
-				uf_power(trhs, &n_trhs);
-				do {
-					do {
-						simp_ssub(trhs, &n_trhs, 0L, 0.0, false, true, 0);
-					} while (uf_power(trhs, &n_trhs));
-				} while (super_factor(trhs, &n_trhs, 1));
-				list_tdebug(3);
-				ep = &trhs[n_trhs];
-				op = 0;
-				for (p1 = &trhs[1]; p1 < ep; p1 += 2) {
-					if (p1->level == 1) {
-						op = p1->token.operatr;
-						if (op == DIVIDE) {
-							goto no_simp;
+			}
+			switch (op) {
+			case TIMES:
+				for (p1 = trhs; p1 < ep;) {
+					b1 = p1;
+					for (;; p1++) {
+						if (p1 >= ep || (p1->kind == OPERATOR && p1->level == 1)) {
+							blt(b1 + 1, p1, (char *) ep - (char *) p1);
+							n_trhs -= p1 - (b1 + 1);
+							b1->kind = CONSTANT;
+							b1->token.constant = 1.0;
+							goto zero_simp;
 						}
-						if (op != TIMES) {
+						if (p1->kind != CONSTANT && p1->kind != OPERATOR
+						    && (p1->kind != VARIABLE || (p1->token.variable & VAR_MASK) > SIGN)) {
 							break;
 						}
 					}
+					p1 = b1;
+					for (p1++; p1 < ep && p1->level > 1; p1 += 2)
+						;
+					p1++;
 				}
-				switch (op) {
-				case TIMES:
-					for (p1 = trhs; p1 < ep;) {
-						b1 = p1;
-						for (;; p1++) {
-							if (p1 >= ep || (p1->kind == OPERATOR && p1->level == 1)) {
-								blt(b1 + 1, p1, (char *) ep - (char *) p1);
-								n_trhs -= p1 - (b1 + 1);
-								b1->kind = CONSTANT;
-								b1->token.constant = 1.0;
-								goto zero_simp;
-							}
-							if (p1->kind != CONSTANT && p1->kind != OPERATOR
-							    && (p1->kind != VARIABLE || (p1->token.variable & VAR_MASK) > SIGN)) {
-								break;
-							}
-						}
-						p1 = b1;
-						for (p1++; p1 < ep && p1->level > 1; p1 += 2)
-							;
-						p1++;
-					}
-					break;
-				case POWER:
-					if ((p1 + 1)->level == 1
-					    && (p1 + 1)->kind == CONSTANT
-					    && (p1 + 1)->token.constant > 0.0) {
-						n_trhs -= 2;
-						goto zero_simp;
-					}
-					break;
+				break;
+			case POWER:
+				p1++;
+				if (p1->level == 1 && p1->kind == CONSTANT && p1->token.constant > 0.0) {
+					n_trhs -= 2;
+					goto zero_simp;
 				}
+				break;
 			}
-			if (zsolve) {
-				debug_string(1, _("Solve for zero completed:"));
-			} else {
-				debug_string(1, _("Solve completed:"));
-			}
-			list_tdebug(1);
-			blt(leftp, tlhs, n_tlhs * sizeof(*leftp));
-			*leftnp = n_tlhs;
-			blt(rightp, trhs, n_trhs * sizeof(*rightp));
-			*rightnp = n_trhs;
-			return success;
+			debug_string(1, _("Solve for zero completed:"));
+		} else {
+			debug_string(1, _("Solve completed:"));
 		}
+		list_tdebug(1);
+		blt(leftp, tlhs, n_tlhs * sizeof(*leftp));
+		*leftnp = n_tlhs;
+		blt(rightp, trhs, n_trhs * sizeof(*rightp));
+		*rightnp = n_trhs;
+		return success;
 	}
 	/* Move what we don't want in the LHS to the RHS. */
 	found_count = 0;
@@ -347,11 +344,10 @@ zero_simp:
 			}
 			if (p1 >= ep) {
 				if (found_count == 0) { /* if solve variable no longer in LHS */
-					for (i = 0; i < n_trhs; i += 2) {
-						if (trhs[i].kind == VARIABLE && trhs[i].token.variable == v) {
-							/* solve variable in RHS */
-							return false;
-						}
+					if (found_var(trhs, n_trhs, v)) {
+						/* solve variable in RHS */
+						debug_string(1, _("Solve variable moved back to RHS, quitting solve routine."));
+						return false;
 					}
 					calc_simp(tlhs, &n_tlhs);
 					calc_simp(trhs, &n_trhs);
@@ -364,15 +360,13 @@ zero_simp:
 					}
 					found = false;
 					for (i = 0; i < n_tlhs; i += 2) {
-						if (tlhs[i].kind == VARIABLE
-						    && tlhs[i].token.variable > IMAGINARY) {
+						if (tlhs[i].kind == VARIABLE && tlhs[i].token.variable > IMAGINARY) {
 							found = true;
 							break;
 						}
 					}
 					for (i = 0; i < n_trhs; i += 2) {
-						if (trhs[i].kind == VARIABLE
-						    && trhs[i].token.variable > IMAGINARY) {
+						if (trhs[i].kind == VARIABLE && trhs[i].token.variable > IMAGINARY) {
 							found = true;
 							break;
 						}
@@ -574,10 +568,9 @@ long	v;
 	simp_ssub(tlhs, &n_tlhs, 0L, 0.0, true, true, 2);
 lonely:
 	ep = &tlhs[n_tlhs];
-	len1 = 0;
-	len2 = 0;
+	len2 = len1 = 0;
 	foundp = false;
-	for (p1 = &tlhs[1];; p1 += 2) {
+	for (p1 = tlhs + 1;; p1 += 2) {
 		if (p1 >= ep) {
 			return false;
 		}
@@ -676,13 +669,13 @@ end:
 
 /*
  * Quadratic and biquadratic solve routine.
- * Solves any equation of the form "0 = ax^(2n)+bx^n+c" for "x",
- * where "x" is an expression containing passed variable "v",
- * and "n" is a constant.
+ * Solves any equation of the form "0 = ax^(2n)+bx^n+c" for "x^n",
+ * where "x" is an expression containing the solve variable,
+ * and "n" is a constant.  Uses the quadratic formula.
  *
- * The equation to solve is in tlhs and trhs, it must be solved for zero.
+ * The equation to solve is in tlhs and trhs, it must already be solved for zero.
  *
- * Return true if successful.
+ * Return true if successful, with solved equation in tlhs and trhs.
  */
 static int
 quad_solve(v)
@@ -780,6 +773,10 @@ long	v;	/* solve variable */
 	}
 	if (high_power == 0.0)
 		return false;
+#if	!SILENT
+	list_var(v, 0);
+	printf(_("Equation is a degree %.*g polynomial in %s.\n"), precision, high_power, var_str);
+#endif
 	if (a1p > trhs && (a1p - 1)->token.operatr == MINUS)
 		opx1 = MINUS;
 	else
@@ -994,7 +991,7 @@ big_bbreak:
 	} else if (high_power == 4.0) {
 		printf(_("Equation was biquadratic.\n"));
 	} else {
-		printf(_("Equation was a degree %.*g quadratic.\n"), precision, high_power);
+		printf(_("Equation was solved with the quadratic formula.\n"));
 	}
 #endif
 	return true;
@@ -1028,7 +1025,7 @@ int		*side2np;	/* pointer to the length of "side2p" */
 	oldn = *side1np;
 	ep = &side1p[oldn];
 	if (*side1np == prev_n1 && *side2np == prev_n2) {
-		if (++repeat_count >= 5) {
+		if (++repeat_count >= 3) {
 			debug_string(1, _("Infinite loop aborted in solve routine."));
 			return false;
 		}
@@ -1078,6 +1075,14 @@ int		*side2np;	/* pointer to the length of "side2p" */
 		*side1np -= operandn + 1;
 		return true;
 	}
+	if (op == MODULUS) {
+		if (get_constant(side2p, *side2np, &d1) && get_constant(operandp, operandn, &d2)) {
+			if (fabs(d1) >= fabs(d2)) {
+				error(_("There are no possible solutions."));
+				return false;
+			}
+		}
+	}
 #if	!SILENT
 	if (debug_level > 0) {
 		switch (op) {
