@@ -1,7 +1,7 @@
 /*
  * Mathomatic unfactorizing (expanding) routines.
  *
- * Copyright (C) 1987-2007 George Gesslein II.
+ * Copyright (C) 1987-2008 George Gesslein II.
  */
 
 #include "includes.h"
@@ -68,8 +68,8 @@ int		*np;
 }
 
 /*
- * Unfactor all power operators.  Same as a call to uf_pplus()
- * and uf_power(), only faster.
+ * Unfactor all power operators.
+ * Same as a call to uf_pplus() and uf_power(), only faster.
  */
 void
 uf_allpower(equation, np)
@@ -82,10 +82,12 @@ int		*np;
 }
 
 /*
- * Unfactor power only if it will help with expansion.
+ * Unfactor power only if it will help with expansion and exponent is <= 100.
  * (a + 1)^2 -> (a + 1)*(a + 1)
+ * Afterwards we also sneak in simplifying division by irrational constants,
+ * because it works best here.
  *
- * uf_times() is usually called after this.
+ * uf_times() is usually called after this to complete the expansion.
  */
 void
 uf_repeat(equation, np)
@@ -160,7 +162,7 @@ int		*np;
 	return rv;
 }
 
-static inline void
+static void
 no_divide(equation, np)
 token_type	*equation;
 int		*np;
@@ -453,6 +455,7 @@ u2_again:
 			}
 		}
 do_repeat:
+		/* unfactor power: (a + 1)^2 -> (a + 1)*(a + 1) */
 		if (ii != 6 && ii != 8)
 			break;
 		i = loc;
@@ -461,7 +464,9 @@ do_repeat:
 		d1 = equation[i+1].token.constant;
 		if (!isfinite(d1) || d1 <= 1.0)
 			break;
-		if (ii != 8) {
+		if (ii != 8) {	/* if true, only do useful expansions */
+			if (d1 > 100.0)	/* ignore exponents over 100 */
+				break;
 			if ((i - b1) > 1 && d1 > 2.0 && fmod(d1, 1.0) != 0.0)
 				break;
 			if ((i - b1) == 1 && equation[b1].kind != CONSTANT)
@@ -497,7 +502,7 @@ do_repeat:
 	return false;
 }
 
-static inline int
+static int
 usp_sub(equation, np, i)
 token_type	*equation;
 int		*np, i;
@@ -668,7 +673,8 @@ int		*np;
 }
 
 /*
- * Convert 1/(k1^k2) to 1/(k1^(k2-1))/k1 if k1 is integer,
+ * Simplify division by irrational constants (roots like 2^.5) by
+ * converting 1/(k1^k2) to 1/(k1^(k2-1))/k1 if k1 is integer,
  * otherwise 1*((1/k1)^k2).
  *
  * Return true if equation side was modified.
